@@ -27,8 +27,9 @@ Foundation; version 2 of the licence.
 #include <string.h>
 #include <stdbool.h>
 #include <signal.h>
+#include <syslog.h>
 
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__NetBSD__)
     #include <sys/cdio.h>
 #elif defined(__linux__)
     #include <linux/cdrom.h>
@@ -59,10 +60,13 @@ GtkWidget * album_year;
 GtkWidget * tracklist;
 GtkWidget * pick_disc;
 
+extern const char* GBLprogramName;
+
 int gbl_null_fd;
 
 int main(int argc, char *argv[])
 {
+    char logStr[1024];
     GtkCellRenderer *renderer;
     
 #ifdef ENABLE_NLS
@@ -98,8 +102,13 @@ int main(int argc, char *argv[])
     global_prefs = get_default_prefs();
     load_prefs(global_prefs);
     
+    openlog("asunder", 0, LOG_USER);
+    snprintf(logStr, 1024, "Starting %s", GBLprogramName);
+    debugLog(logStr);
+    
     add_pixmap_directory(PACKAGE_DATA_DIR "/pixmaps");
-    debugLog("Pixmap dir: " PACKAGE_DATA_DIR "/pixmaps\n");
+    snprintf(logStr, 1024, "Pixmap dir: "PACKAGE_DATA_DIR "/pixmaps\n");
+    debugLog(logStr);
     
     win_main = create_main();
     album_artist = lookup_widget(win_main, "album_artist");
@@ -192,7 +201,7 @@ bool check_disc(char * cdrom)
     bool ret = false;
     int status;
     
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__NetBSD__)
     struct ioc_read_subchannel cdsc;
     struct cd_sub_channel_info data;
 #endif
@@ -229,7 +238,7 @@ bool check_disc(char * cdrom)
     static bool alreadyKnowGood = false; /* check when program just started */
     static bool alreadyCleared = true; /* no need to clear when program just started */
     
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__NetBSD__)
     bzero(&cdsc, sizeof(cdsc));
     cdsc.data = &data;
     cdsc.data_len = sizeof(data);
@@ -356,7 +365,7 @@ void eject_disc(char * cdrom)
     //~ {
         //~ ioctl(fd, CDROMCLOSETRAY, CDSL_CURRENT);
     //~ } else {
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__NetBSD__)
             ioctl(fd, CDIOCALLOW);
             ioctl(fd, CDIOCEJECT);
 #elif defined(__linux__)
@@ -372,7 +381,6 @@ void eject_disc(char * cdrom)
         const char* const args[] = {"eject", cdrom, NULL};
         execvp(args[0], (char*const*)args);
         
-        printf("Should never see this, why did the call to 'eject' fail?\n");
         debugLog("Should never see this, why did the call to 'eject' fail?\n");
         exit(1);
     }
@@ -387,12 +395,18 @@ static GList * gbl_matches = NULL;
 
 gpointer cddb_query_thread_run(gpointer data)
 {
+    char logStr[1024];
     int i;
     
     gbl_cddb_query_thread_num_matches = cddb_query(gbl_cddb_query_thread_conn, gbl_cddb_query_thread_disc);
     if(gbl_cddb_query_thread_num_matches == -1)
         gbl_cddb_query_thread_num_matches = 0;
     
+    snprintf(logStr, 1024, "Found %d CDDB matches", gbl_cddb_query_thread_num_matches);
+    debugLog(logStr);
+    
+    gbl_matches = NULL;
+    
     // make a list of all the matches
     for (i = 0; i < gbl_cddb_query_thread_num_matches; i++)
     {
@@ -471,6 +485,7 @@ GList * lookup_disc(cddb_disc_t * disc)
 
 cddb_disc_t * read_disc(char * cdrom)
 {
+    char logStr[1024];
     int fd;
     int status;
     int i;
@@ -479,6 +494,12 @@ cddb_disc_t * read_disc(char * cdrom)
     struct ioc_read_toc_single_entry te;
     struct ioc_read_subchannel cdsc;
     struct cd_sub_channel_info data;
+#elif defined(__NetBSD__)
+    struct ioc_toc_header th;
+    struct ioc_read_toc_entry te;
+    struct cd_toc_entry toc ;
+    struct ioc_read_subchannel cdsc;
+    struct cd_sub_channel_info data;
 #elif defined(__linux__)
     struct cdrom_tochdr th;
     struct cdrom_tocentry te;
@@ -510,8 +531,8 @@ cddb_disc_t * read_disc(char * cdrom)
         // see if we can read the disc's table of contents (TOC).
         if (ioctl(fd, CDIOREADTOCHEADER, &th) == 0)
         {
-            debugLog("starting track: %d\n", th.starting_track);
-            debugLog("ending track: %d\n", th.ending_track);
+            snprintf(logStr, 1024, "starting track: %d, ending track: %d\n", th.starting_track, th.ending_track);
+            debugLog(logStr);
             
             disc = cddb_disc_new();
             if (disc == NULL)
@@ -549,6 +570,60 @@ cddb_disc_t * read_disc(char * cdrom)
             }
         }
     }
+#elif defined(__NetBSD__)
+    // read disc status info
+    bzero(&cdsc,sizeof(cdsc));
+    cdsc.data = &data;
+    cdsc.data_len = sizeof(data);
+    cdsc.data_format = CD_CURRENT_POSITION;
+    cdsc.address_format = CD_MSF_FORMAT;
+    status = ioctl(fd, CDIOCREADSUBCHANNEL, (char *)&cdsc);
+    if (status >= 0)
+    {
+        // see if we can read the disc's table of contents (TOC).
+        if (ioctl(fd, CDIOREADTOCHEADER, &th) == 0)
+        {
+            snprintf(logStr, 1024, "starting track: %d, ending track: %d\n", th.starting_track, th.ending_track);
+            debugLog(logStr);
+            
+            disc = cddb_disc_new();
+            if (disc == NULL)
+                fatalError("cddb_disc_new() failed. Out of memory?");
+            
+            te.address_format = CD_LBA_FORMAT;
+            te.data = &toc ;
+            te.data_len=sizeof(struct cd_toc_entry) ;
+            for (i=th.starting_track; i<=th.ending_track; i++)
+            {
+                te.starting_track = i;
+                if ((ioctl(fd, CDIOREADTOCENTRIES, &te)) == 0)
+                {
+                    if (te.data->control & 0x04)
+                    {
+                        // track is a DATA track. make sure its "rip" box is not checked by default
+                        track_format[i] = FALSE;
+                    } else {
+                        track_format[i] = TRUE;
+                    }
+
+                    track = cddb_track_new();
+                    if (track == NULL)
+                        fatalError("cddb_track_new() failed. Out of memory?");
+                    
+                    cddb_track_set_frame_offset(track, te.data->addr.lba+SECONDS_TO_FRAMES(2));
+                    snprintf(trackname, 9, "Track %d", i);
+                    cddb_track_set_title(track, trackname);
+                    cddb_track_set_artist(track, "Unknown Artist");
+                    cddb_disc_add_track(disc, track);
+                }
+            }
+            te.starting_track = 0xAA;
+            if (ioctl(fd, CDIOREADTOCENTRIES, &te) == 0)
+             {
+                cddb_disc_set_length(disc, (te.data->addr.lba+SECONDS_TO_FRAMES(2))/SECONDS_TO_FRAMES(1));
+            }
+        }
+    }
 #elif defined(__linux__)
     // read disc status info
     status = ioctl(fd, CDROM_DISC_STATUS, CDSL_CURRENT);
@@ -557,8 +632,8 @@ cddb_disc_t * read_disc(char * cdrom)
         // see if we can read the disc's table of contents (TOC).
         if (ioctl(fd, CDROMREADTOCHDR, &th) == 0)
         {
-            debugLog("starting track: %d\n", th.cdth_trk0);
-            debugLog("ending track: %d\n", th.cdth_trk1);
+            snprintf(logStr, 1024, "starting track: %d, ending track: %d\n", th.cdth_trk0, th.cdth_trk1);
+            debugLog(logStr);
             
             disc = cddb_disc_new();
             if (disc == NULL)
@@ -613,7 +688,10 @@ void update_tracklist(cddb_disc_t * disc)
     unsigned disc_year = cddb_disc_get_year(disc);
     cddb_track_t * track;
     bool singleartist;
+    char logStr[1024];
     
+    sprintf(logStr, "update_tracklist() disk '%s' '%s' '%s'\n", disc_artist, disc_title, disc_genre);
+    debugLog(logStr);
     if (disc_artist != NULL)
     {
         //trim_chars(disc_artist, BADCHARS);			// lnr	//Commented out by mrpl
